pub struct AngularPannedSource(/* private fields */);Implementations
Sourceimpl AngularPannedSource
impl AngularPannedSource
pub fn new( context: &Context, panner_strategy: PannerStrategy, azimuth: f64, elevation: f64, ) -> Result<AngularPannedSource>
pub fn gain(&self) -> DoubleProperty<'_>
pub fn get_filter(&self) -> Result<BiquadConfig>
pub fn set_filter(&self, cfg: &BiquadConfig) -> Result<()>
pub fn get_filter_direct(&self) -> Result<BiquadConfig>
pub fn set_filter_direct(&self, cfg: &BiquadConfig) -> Result<()>
pub fn get_filter_effects(&self) -> Result<BiquadConfig>
pub fn set_filter_effects(&self, cfg: &BiquadConfig) -> Result<()>
pub fn elevation(&self) -> DoubleProperty<'_>
pub fn azimuth(&self) -> DoubleProperty<'_>
pub fn handle(&self) -> &Handle
pub fn into_handle(self) -> Handle
pub fn get_type(&self) -> Result<ObjectType>
Sourcepub fn cast_to<T: CastTarget>(&self) -> Result<Option<T>>
pub fn cast_to<T: CastTarget>(&self) -> Result<Option<T>>
Try to cast this object to another object type. Will return
Ok(None) if this is because of a type mismatch, otherwise Err.
Clones self on success in order to prevent throwing the object
away on error.
pub fn get_userdata(&self) -> Result<Option<Arc<dyn Any + Send + Sync>>>
pub fn set_userdata( &self, userdata: Option<impl Any + Send + Sync>, ) -> Result<()>
pub fn config_delete_behavior( &self, config: &DeleteBehaviorConfig, ) -> Result<()>
pub fn current_time(&self) -> DoubleProperty<'_>
pub fn suggested_automation_time(&self) -> DoubleProperty<'_>
pub fn pause(&self) -> Result<()>
pub fn play(&self) -> Result<()>
pub fn add_generator<T: IsGenerator>(&self, generator: &T) -> Result<()>
pub fn remove_generator<T: IsGenerator>(&self, generator: &T) -> Result<()>