pub struct Generator(/* private fields */);Expand description
Represents the generator “base class”. A From impl lets you get to this object from any kind of generator.
Implementations
Sourceimpl Generator
impl Generator
pub fn handle(&self) -> &Handle
pub fn into_handle(self) -> Handle
pub fn get_type(&self) -> Result<ObjectType>
Sourcepub fn cast_to<T: CastTarget>(&self) -> Result<Option<T>>
pub fn cast_to<T: CastTarget>(&self) -> Result<Option<T>>
Try to cast this object to another object type. Will return
Ok(None) if this is because of a type mismatch, otherwise Err.
Clones self on success in order to prevent throwing the object
away on error.
pub fn get_userdata(&self) -> Result<Option<Arc<dyn Any + Send + Sync>>>
pub fn set_userdata( &self, userdata: Option<impl Any + Send + Sync>, ) -> Result<()>
pub fn config_delete_behavior( &self, config: &DeleteBehaviorConfig, ) -> Result<()>
pub fn current_time(&self) -> DoubleProperty<'_>
pub fn suggested_automation_time(&self) -> DoubleProperty<'_>
pub fn pause(&self) -> Result<()>
pub fn play(&self) -> Result<()>
pub fn pitch_bend(&self) -> DoubleProperty<'_>
pub fn gain(&self) -> DoubleProperty<'_>