pub struct Handle(/* private fields */);Implementations
Sourceimpl Handle
impl Handle
pub fn new(h: syz_Handle) -> Handle
pub fn handle(&self) -> &Handle
pub fn into_handle(self) -> Handle
Sourcepub fn get_type(&self) -> Result<ObjectType>
pub fn get_type(&self) -> Result<ObjectType>
Get the object’s type if possible. THis function will fail if Synthizer is not initialized.
Sourcepub fn cast_to<T: CastTarget>(&self) -> Result<Option<T>>
pub fn cast_to<T: CastTarget>(&self) -> Result<Option<T>>
Try to cast this object to another object type. Will return
Ok(None) if this is because of a type mismatch, otherwise Err.
Clones self on success in order to prevent throwing the object
away on error.
Sourcepub fn get_userdata(&self) -> Result<Option<Arc<dyn Any + Send + Sync>>>
pub fn get_userdata(&self) -> Result<Option<Arc<dyn Any + Send + Sync>>>
Get this handle’s userdata.
Sourcepub fn set_userdata(
&self,
userdata: Option<impl Any + Send + Sync>,
) -> Result<()>
pub fn set_userdata( &self, userdata: Option<impl Any + Send + Sync>, ) -> Result<()>
Set the userdata for this handle.
pub fn config_delete_behavior( &self, config: &DeleteBehaviorConfig, ) -> Result<()>